@@ -9,7 +9,19 @@ class datetimeFormat():
     """
     
     yyyyMMddhhmmss = '%Y%m%d%H%M%S'
-    """ yyyyMMddhhmmss"""
+    """ yyyyMMddhhmmss """
+
+    yyyyMMddhhmm = '%Y%m%d%H%M%'
+    """ yyyyMMddhhmm """
+
+    yyyyMMdd = '%Y%m%d'
+    """ yyyyMMdd """
+
+    yyMMdd = '%y%m%d'
+    """ yyMMdd """
+
+    MMdd = '%m%d'
+    """ MMdd """
 
     updinfo = '%Y/%m/%d %H:%M:%S'
     """ updinfo列用 """
@@ -48,13 +60,7 @@ def getNow(fmt:str=''):
     
     # 日本時刻取得
     nowDateTime = datetime.datetime.now(datetime.timezone(datetime.timedelta(hours=9)))
-    # if fmt == '':
-    #     return nowDateTime
-    # elif datetimeFormat.yyyyMMddhhmmss == fmt:
-    #     # yyyyMMddhhmmss形式に変換
-    #     return nowDateTime.strftime(fmt)
-    # else:
-    #     return nowDateTime
+
     return nowDateTime if fmt == '' else nowDateTime.strftime(fmt)
 
 def addDays(targetDate, addDays: int):
